(broker-utils)=
# Broker Utilities

The `broker_utils.py` module contains the `BrokerUtils` class, containing general utility methods 
for the broker API's.



```{eval-rst}
.. autoclass:: autotrader.brokers.broker_utils.BrokerUtils
   :members:
   :private-members:
```
